California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 027 - ALLOWS ONLINE AND MOBILE SPORTS WAGERING. INITIATIVE CONSTITUTIONAL AMENDMENT AND STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1440682 | YES ON 27 - CALIFORNIANS FOR SOLUTIONS TO HOMELESSNESS AND MENTAL HEALTH SUPPORT, A COALITION OF HOUSING AND MENTAL HEALTH EXPERTS, CONCERNED TAXPAYERS AND DIGITAL SPORTS ENTERTAINMENT AND GAMING ... | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1443032 | NO ON 27 - CALIFORNIANS FOR TRIBAL SOVEREIGNTY AND SAFE GAMING, SPONSORED BY TRIBAL ORGANIZATIONS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1424396 | YES ON 26, NO ON 27 - COALITION FOR SAFE, RESPONSIBLE GAMING, SPONSORED BY CALIFORNIA INDIAN TRIBES | OPPOSE